.. currentmodule:: tango

.. highlight:: python
   :linenothreshold: 3

.. _testing-test-context:

=====================================
Device Test Context Classes API
=====================================

The API of the testing classes are described here.  For an overview of their behaviour,
see :ref:`testing-approaches`.

DeviceTestContext
-----------------

.. autoclass:: tango.test_context.DeviceTestContext
    :show-inheritance:
    :members:
    :inherited-members:

MultiDeviceTestContext
----------------------
.. autoclass:: tango.test_context.MultiDeviceTestContext
    :show-inheritance:
    :members:
    :inherited-members:
